"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildSchema = void 0;
const fs = require("fs");
const graphql_tools_1 = require("graphql-tools");
const path = require("path");
const scalar_resolvers_1 = require("./lib/scalar_resolvers");
const buildHasuraSchema_1 = require("./buildHasuraSchema");
function buildSchema(hasuraUri) {
    return __awaiter(this, void 0, void 0, function* () {
        const hasuraSchema = yield buildHasuraSchema_1.buildHasuraSchema(hasuraUri);
        return graphql_tools_1.makeExecutableSchema({
            resolvers: Object.assign({}, scalar_resolvers_1.scalarResolvers, {
                Query: {
                    blocks: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'blocks',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    blocks_aggregate: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'blocks_aggregate',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    epochs: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'epochs',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    epochs_aggregate: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'epochs_aggregate',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    cardano: (_root, _args, context, info) => __awaiter(this, void 0, void 0, function* () {
                        const result = yield graphql_tools_1.delegateToSchema({
                            context,
                            fieldName: 'cardano',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                        return result[0];
                    }),
                    transactions: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'transactions',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    transactions_aggregate: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'transactions_aggregate',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    utxos: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'utxos',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    },
                    utxos_aggregate: (_root, args, context, info) => {
                        return graphql_tools_1.delegateToSchema({
                            args,
                            context,
                            fieldName: 'utxos_aggregate',
                            info,
                            operation: 'query',
                            schema: hasuraSchema
                        });
                    }
                }
            }),
            typeDefs: fs.readFileSync(path.resolve(__dirname, 'schema.graphql'), 'utf-8')
        });
    });
}
exports.buildSchema = buildSchema;
//# sourceMappingURL=executableSchema.js.map